==> snowmobile-0.1.14b2.tar.gz: snowmobile-0.1.14b2/docs/snippets.md <==
# Snippets
<hr class="sn-grey">

This is a generated reference page for complete code snippets used throughout
the rest of the documentation.

<hr class="sn-grey">

<style>
h2 {
    background: radial-gradient(#11838e91,#11838e00);
    border-bottom: solid thin #6c757d12;
    border-top: solid thin #6c757d12;
    margin-bottom: 1rem;
    margin-top: 2rem;
    color: #212529;
    font-weight: 400;
    padding-top: 0.2em;
    padding-bottom: 0.2em;
    padding-left: 0.2em;
}
h3 {
    padding-left: 1.1em;
}
h2 + hr + h3 {
    padding-top: 0.5em;
}
h3[id$="py"] + hr, h3[id$="sql"] + hr {
    margin: -0.5em 2em -0.5em 1rem;
    border-color: #206f8d8f;
    border-style: solid;
}


.md-typeset p ~ .highlight-python.notranslate, .md-typeset .highlight-sql.notranslate, .md-typeset .highlight-default, .md-typeset .highlight-toml.notranslate {
    margin-left: unset;
    margin-right: unset;
    margin-bottom: unset;
}

.md-typeset .sn-pre-code ~ .highlight-python.notranslate, .md-typeset .highlight-sql.notranslate, .md-typeset .highlight-default, .md-typeset .highlight-toml.notranslate {
    margin-left: unset;
    margin-right: unset;
}

ul.md-nav__list>li.md-nav__item:last-child {
    padding-bottom: 0.5em;
}
li.md-nav__item>a[href$="py"]>em {
    color: #212529;
}
li.md-nav__item>a[href$="sql"] {
    color: #666666b0
}
nav.md-nav.md-nav--secondary a[href$="page-root"] {
    margin-bottom: 1em;
}

@media only screen and (max-width: 59.9375em) {
    .md-typeset .sn-indent-h-cell {
        padding-left: 0.4rem;
        padding-right: 0.4rem;
    }
    h3 {
        padding-left: 0.4em;
    }
    h3[id$="py"] + hr, h3[id$="sql"] + hr {
        margin: -0.5em 0.4rem -0.5em 0.4rem;
    }
    div.sn-link-group.sn-snippet-only {
        padding-right: 0.4rem;
    }
    li.md-nav__item>a>em {
        color: unset;
    }
    li.md-nav__item>a[href$="py"]>em {
        color: #f8f9fa;
    }
    li.md-nav__item>a[href$="sql"] {
        color: #f8f9faa3;
    }
    nav.md-nav.md-nav--secondary a[href$="page-root"] {
        margin-bottom: unset;
    }
}

</style>

[comment]: <> (--- snippets.py split point; ALL GENERATED BELOW THIS POINT ---)
+++
<br>

## Configuration

### *inspect_configuration.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/configuration/inspect_configuration.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/configuration/inspect_configuration.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/configuration/inspect_configuration.py
:language: python
:lines: 1-18
:lineno-start: 1
```
````
<br>

<br>

## Overview

### *sample_table.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/overview/sample_table.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/overview/sample_table.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/overview/sample_table.sql
:language: sql
:lines: 1-36
:lineno-start: 1
```
````
<br>

<br>

## Script

### *overview.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/overview.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/overview.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/overview.sql
:language: sql
:lines: 1-34
:lineno-start: 1
```
````
<br>

### *keyword_exceptions.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/keyword_exceptions.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/keyword_exceptions.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/keyword_exceptions.sql
:language: sql
:lines: 1-10
:lineno-start: 1
```
````
<br>

### *markup.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/markup.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/markup.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/markup.sql
:language: sql
:lines: 1-6
:lineno-start: 1
```
````
<br>

### *overview-statement-intro.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/overview-statement-intro.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/overview-statement-intro.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/overview-statement-intro.py
:language: python
:lines: 1-68
:lineno-start: 1
```
````
<br>

### *tags_multi-line.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/tags_multi-line.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/tags_multi-line.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/tags_multi-line.sql
:language: sql
:lines: 1-13
:lineno-start: 1
```
````
<br>

### *tags_single-line.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/tags_single-line.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/script/tags_single-line.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/tags_single-line.sql
:language: sql
:lines: 1-8
:lineno-start: 1
```
````
<br>

<br>

## Snowmobile

### *connecting.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connecting.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/connecting.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connecting.py
:language: python
:lines: 1-18
:lineno-start: 1
```
````
<br>

### *connector_cursor_note.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_cursor_note.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/connector_cursor_note.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_cursor_note.py
:language: python
:lines: 1-19
:lineno-start: 1
```
````
<br>

### *connector_delayed1.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_delayed1.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/connector_delayed1.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_delayed1.py
:language: python
:lines: 1-17
:lineno-start: 1
```
````
<br>

### *connector_delayed2.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_delayed2.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/connector_delayed2.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_delayed2.py
:language: python
:lines: 1-23
:lineno-start: 1
```
````
<br>

### *ensure_alive.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/ensure_alive.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/ensure_alive.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/ensure_alive.py
:language: python
:lines: 1-39
:lineno-start: 1
```
````
<br>

### *executing.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/executing.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/executing.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/executing.py
:language: python
:lines: 1-41
:lineno-start: 1
```
````
<br>

### *inspect_connector.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/inspect_connector.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/inspect_connector.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/inspect_connector.py
:language: python
:lines: 1-17
:lineno-start: 1
```
````
<br>

### *specifying_configuration.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/specifying_configuration.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/specifying_configuration.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/specifying_configuration.py
:language: python
:lines: 1-10
:lineno-start: 1
```
````
<br>

### *specifying_configuration2.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/specifying_configuration2.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/specifying_configuration2.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/specifying_configuration2.py
:language: python
:lines: 1-46
:lineno-start: 1
```
````
<br>

### *verify_default_alias_change.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/verify_default_alias_change.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/snowmobile/verify_default_alias_change.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/verify_default_alias_change.py
:language: python
:lines: 1-11
:lineno-start: 1
```
````
<br>

<br>

## SQL

### *sql_cross_schema.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/sql/sql_cross_schema.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.1/docs/snippets/sql/sql_cross_schema.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/sql/sql_cross_schema.py
:language: python
:lines: 1-81
:lineno-start: 1
```
````
<br>

==> snowmobile-0.2.0b15.tar.gz: snowmobile-0.2.0b15/docs/snippets.md <==
# Snippets
<hr class="sn-grey">

This is a generated reference page for complete code snippets used throughout
the rest of the documentation.

<hr class="sn-grey">

<style>
h2 {
    background: radial-gradient(#11838e91,#11838e00);
    /*border-bottom: solid thin #6c757d12;*/
    /*border-top: solid thin #6c757d12;*/
    border: none;
    margin-bottom: 1rem;
    margin-top: 2rem;
    color: #212529;
    font-weight: 400;
    padding-top: 0.2em;
    padding-bottom: 0.2em;
    padding-left: 0.2em;
}
h3 {
    padding-left: 1.1em;
}
h2 + hr + h3 {
    padding-top: 0.5em;
}
h3[id$="py"] + hr, h3[id$="sql"] + hr {
    margin: -0.5em 2em -0.5em 1rem;
    border-color: #206f8d8f;
    border-style: solid;
}

.sn-download-snippet p a:hover {
    background-color: #28698b;
    padding-top: 0.2rem;
}
.sn-snippet-git-link p a:hover {
    background-color: #28698b;
    padding-top: 0.2rem;
}

.md-typeset p ~ .highlight-python.notranslate, .md-typeset .highlight-sql.notranslate, .md-typeset .highlight-default, .md-typeset .highlight-toml.notranslate {
    margin-left: unset;
    margin-right: unset;
    margin-bottom: unset;
}

.md-typeset .sn-pre-code ~ .highlight-python.notranslate, .md-typeset .highlight-sql.notranslate, .md-typeset .highlight-default, .md-typeset .highlight-toml.notranslate {
    margin-left: unset;
    margin-right: unset;
}

ul.md-nav__list>li.md-nav__item:last-child {
    padding-bottom: 0.5em;
}
li.md-nav__item>a[href$="py"]>em {
    color: #f0f8ffcf;
}
li.md-nav__item>a[href$="-sql"] {
    color: #f8f9fa8f;
}
nav.md-nav.md-nav--secondary a[href$="page-root"] {
    margin-bottom: 1em;
}

@media only screen and (max-width: 59.9375em) {
    .md-typeset .sn-indent-h-cell {
        padding-left: 0.4rem;
        padding-right: 0.4rem;
    }
    h3 {
        padding-left: 0.4em;
    }
    h3[id$="py"] + hr, h3[id$="sql"] + hr {
        margin: -0.5em 0.4rem -0.5em 0.4rem;
    }
    div.sn-link-group.sn-snippet-only {
        padding-right: 0.4rem;
    }
    li.md-nav__item>a>em {
        color: unset;
    }
    li.md-nav__item>a[href$="py"]>em {
        color: #f8f9fa;
    }
    li.md-nav__item>a[href$="sql"] {
        color: #f8f9faa3;
    }
    nav.md-nav.md-nav--secondary a[href$="page-root"] {
        margin-bottom: unset;
    }
}

</style>

[comment]: <> (--- snippets.py split point; ALL GENERATED BELOW THIS POINT ---)
+++
<br>

## Configuration

### *inspect_configuration.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/configuration/inspect_configuration.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/configuration/inspect_configuration.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/configuration/inspect_configuration.py
:language: python
:lines: 1-18
:lineno-start: 1
```
````
<br>

<br>

## Overview

### *sample_table.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/overview/sample_table.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/overview/sample_table.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/overview/sample_table.sql
:language: sql
:lines: 1-36
:lineno-start: 1
```
````
<br>

<br>

## Script

### *intro.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/intro.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/intro.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/intro.sql
:language: sql
:lines: 1-21
:lineno-start: 1
```
````
<br>

### *keyword_exceptions.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/keyword_exceptions.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/keyword_exceptions.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/keyword_exceptions.sql
:language: sql
:lines: 1-10
:lineno-start: 1
```
````
<br>

### *markup.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/markup.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/markup.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/markup.sql
:language: sql
:lines: 1-6
:lineno-start: 1
```
````
<br>

### *overview-statement-intro.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/overview-statement-intro.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/overview-statement-intro.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/overview-statement-intro.py
:language: python
:lines: 1-67
:lineno-start: 1
```
````
<br>

### *overview.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/overview.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/overview.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/overview.sql
:language: sql
:lines: 1-32
:lineno-start: 1
```
````
<br>

### *tags_multi-line.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/tags_multi-line.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/tags_multi-line.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/tags_multi-line.sql
:language: sql
:lines: 1-13
:lineno-start: 1
```
````
<br>

### *tags_single-line.sql*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/script/tags_single-line.sql>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/script/tags_single-line.sql"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/script/tags_single-line.sql
:language: sql
:lines: 1-8
:lineno-start: 1
```
````
<br>

<br>

## Snowmobile

### *connecting.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connecting.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/connecting.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connecting.py
:language: python
:lines: 1-18
:lineno-start: 1
```
````
<br>

### *connector_cursor_note.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_cursor_note.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/connector_cursor_note.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_cursor_note.py
:language: python
:lines: 1-19
:lineno-start: 1
```
````
<br>

### *connector_delayed1.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_delayed1.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/connector_delayed1.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_delayed1.py
:language: python
:lines: 1-17
:lineno-start: 1
```
````
<br>

### *connector_delayed2.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/connector_delayed2.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/connector_delayed2.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/connector_delayed2.py
:language: python
:lines: 1-23
:lineno-start: 1
```
````
<br>

### *ensure_alive.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/ensure_alive.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/ensure_alive.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/ensure_alive.py
:language: python
:lines: 1-39
:lineno-start: 1
```
````
<br>

### *executing.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/executing.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/executing.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/executing.py
:language: python
:lines: 1-41
:lineno-start: 1
```
````
<br>

### *inspect_connector.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/inspect_connector.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/inspect_connector.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/inspect_connector.py
:language: python
:lines: 1-17
:lineno-start: 1
```
````
<br>

### *specifying_configuration.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/specifying_configuration.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/specifying_configuration.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/specifying_configuration.py
:language: python
:lines: 1-10
:lineno-start: 1
```
````
<br>

### *specifying_configuration2.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/specifying_configuration2.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/specifying_configuration2.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/specifying_configuration2.py
:language: python
:lines: 1-46
:lineno-start: 1
```
````
<br>

### *verify_default_alias_change.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/snowmobile/verify_default_alias_change.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/snowmobile/verify_default_alias_change.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/snowmobile/verify_default_alias_change.py
:language: python
:lines: 1-11
:lineno-start: 1
```
````
<br>

<br>

## SQL

### *sql_cross_schema.py*
---

````{div} sn-link-group, sn-snippet-only
```{div} sn-download-snippet 
{download}`Download<./snippets/sql/sql_cross_schema.py>`
```
```{div} sn-snippet-git-link 
<a class="reference external" href="https://github.com/GEM7318/Snowmobile/tree/0.2.0/docs/snippets/sql/sql_cross_schema.py"><span>text</span></a>
```
````
````{div} sn-indent-h-cell
```{literalinclude} /snippets/sql/sql_cross_schema.py
:language: python
:lines: 1-81
:lineno-start: 1
```
````
<br>
